@@ -23,15 +23,13 @@
 //! For example, a PC with no network card might not contain a network driver,
 //! therefore all the network protocols will be unavailable.
 
-#![cfg_attr(
-    feature = "exts",
-    feature(allocator_api, alloc_layout_extra, vec_spare_capacity)
-)]
+#![cfg_attr(feature = "exts", feature(allocator_api, alloc_layout_extra))]
 #![feature(auto_traits)]
 #![feature(control_flow_enum)]
 #![feature(try_trait_v2)]
 #![feature(abi_efiapi)]
 #![feature(negative_impls)]
+#![feature(ptr_metadata)]
 #![no_std]
 // Enable some additional warnings and lints.
 #![warn(missing_docs, unused)]
@@ -53,7 +51,7 @@ pub use self::data_types::{unsafe_guid, Identify};
 pub use self::data_types::{CStr16, CStr8, Char16, Char8, Event, Guid, Handle};
 
 mod result;
-pub use self::result::{Completion, Result, ResultExt, Status};
+pub use self::result::{Completion, Error, Result, ResultExt, Status};
 
 pub mod table;
 
